@@ -13,6 +13,7 @@ from vessel.steps import VaultInitStep, VaultSaveSecretsStep, GenerateKeysStep,
 from vessel.pipeline import Pipeline, Payload
 from vessel.logging import logger
 from vessel.version import VERSION, LATEST_AGENT, LATEST_SENTINEL
+from vessel.utilities import sanitizeClusterName
 import kubernetes
 from kubernetes.client.rest import ApiException
 
@@ -196,8 +197,8 @@ def update(ctx, token, vault, sentinel_tag, agent_tag):
   namespace = devops['vessel_namespace']
   img_base = devops['images_base_url']
   k8s_token = devops['devops_sa_token']
-  cluster_name = urllib.parse.quote(registration['cluster']['result']['name'].lower().replace(" ", "-"))
-
+  cluster_name = sanitizeClusterName(registration['cluster']['result']['name'])
+  
   # Init kube client
   click.echo('Creating kubernetes client configuration...')
   configuration = kubernetes.client.Configuration()
